@@ -1,3 +1,17 @@
+// Copyright 2005-2020 Google LLC
+//
+// Licensed under the Apache License, Version 2.0 (the 'License');
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an 'AS IS' BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+//
 // See www.openfst.org for extensive documentation on this weighted
 // finite-state transducer library.
 //
@@ -35,8 +49,9 @@ int fstconvert_main(int argc, char **argv) {
   std::unique_ptr<FstClass> ifst(FstClass::Read(in_name));
   if (!ifst) return 1;
 
-  if (ifst->FstType() != FLAGS_fst_type) {
-    std::unique_ptr<FstClass> ofst(s::Convert(*ifst, FLAGS_fst_type));
+  if (ifst->FstType() != FST_FLAGS_fst_type) {
+    std::unique_ptr<FstClass> ofst(
+        s::Convert(*ifst, FST_FLAGS_fst_type));
     if (!ofst) return 1;
     return !ofst->Write(out_name);
   } else {
