@@ -1,3 +1,17 @@
+// Copyright 2005-2020 Google LLC
+//
+// Licensed under the Apache License, Version 2.0 (the 'License');
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an 'AS IS' BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+//
 // See www.openfst.org for extensive documentation on this weighted
 // finite-state transducer library.
 //
@@ -39,10 +53,12 @@ int fstprune_main(int argc, char **argv) {
   if (!fst) return 1;
 
   const auto weight_threshold =
-      FLAGS_weight.empty() ? WeightClass::Zero(fst->WeightType())
-                           : WeightClass(fst->WeightType(), FLAGS_weight);
+      FST_FLAGS_weight.empty()
+          ? WeightClass::Zero(fst->WeightType())
+          : WeightClass(fst->WeightType(), FST_FLAGS_weight);
 
-  s::Prune(fst.get(), weight_threshold, FLAGS_nstate, FLAGS_delta);
+  s::Prune(fst.get(), weight_threshold, FST_FLAGS_nstate,
+           FST_FLAGS_delta);
 
   return !fst->Write(out_name);
 }
