@@ -1,3 +1,17 @@
+// Copyright 2005-2020 Google LLC
+//
+// Licensed under the Apache License, Version 2.0 (the 'License');
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an 'AS IS' BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+//
 // See www.openfst.org for extensive documentation on this weighted
 // finite-state transducer library.
 //
@@ -39,7 +53,7 @@ int fstreverse_main(int argc, char **argv) {
 
   VectorFstClass ofst(ifst->ArcType());
 
-  s::Reverse(*ifst, &ofst, FLAGS_require_superinitial);
+  s::Reverse(*ifst, &ofst, FST_FLAGS_require_superinitial);
 
   return !ofst.Write(out_name);
 }
