@@ -1,3 +1,17 @@
+// Copyright 2005-2020 Google LLC
+//
+// Licensed under the Apache License, Version 2.0 (the 'License');
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an 'AS IS' BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+//
 // See www.openfst.org for extensive documentation on this weighted
 // finite-state transducer library.
 //
@@ -13,10 +27,11 @@
 #include <fst/script/reweight.h>
 #include <fst/script/text-io.h>
 
-DECLARE_bool(to_final);
+DECLARE_string(reweight_type);
 
 int fstreweight_main(int argc, char **argv) {
   namespace s = fst::script;
+  using fst::ReweightType;
   using fst::script::MutableFstClass;
   using fst::script::WeightClass;
 
@@ -43,7 +58,14 @@ int fstreweight_main(int argc, char **argv) {
     return 1;
   }
 
-  s::Reweight(fst.get(), potential, s::GetReweightType(FLAGS_to_final));
+  ReweightType reweight_type;
+  if (!s::GetReweightType(FST_FLAGS_reweight_type, &reweight_type)) {
+    LOG(ERROR) << argv[0] << ": Unknown or unsupported reweight type: "
+               << FST_FLAGS_reweight_type;
+    return 1;
+  }
+
+  s::Reweight(fst.get(), potential, reweight_type);
 
   return !fst->Write(out_name);
 }
