@@ -1,3 +1,17 @@
+// Copyright 2005-2020 Google LLC
+//
+// Licensed under the Apache License, Version 2.0 (the 'License');
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an 'AS IS' BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+//
 // See www.openfst.org for extensive documentation on this weighted
 // finite-state transducer library.
 //
@@ -38,8 +52,8 @@ int fstcompress_main(int argc, char **argv) {
   const std::string out_name =
       (argc > 2 && (strcmp(argv[2], "-") != 0)) ? argv[2] : "";
 
-  if (FLAGS_decode) {
-    VectorFstClass fst(FLAGS_arc_type);
+  if (FST_FLAGS_decode) {
+    VectorFstClass fst(FST_FLAGS_arc_type);
     if (!s::Decompress(in_name, &fst)) {
       FSTERROR() << "Decompression failed";
       return 1;
