@@ -1,3 +1,17 @@
+// Copyright 2005-2020 Google LLC
+//
+// Licensed under the Apache License, Version 2.0 (the 'License');
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an 'AS IS' BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+//
 #include <fst/flags.h>
 
 DEFINE_string(key_prefix, "", "Prefix to append to keys");
@@ -13,7 +27,7 @@ DEFINE_string(arc_type, "standard", "Output arc type");
 DEFINE_string(entry_type, "line",
               "Entry type: one of : "
               "\"file\" (one FST per file), \"line\" (one FST per line)");
-DEFINE_string(fst_type, "vector", "Output FST type");
+DEFINE_string(fst_type, "", "Output FST type");
 DEFINE_string(token_type, "symbol",
               "Token type: one of : "
               "\"symbol\", \"byte\", \"utf8\"");
