@@ -1,3 +1,17 @@
+// Copyright 2005-2020 Google LLC
+//
+// Licensed under the Apache License, Version 2.0 (the 'License');
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an 'AS IS' BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+//
 // See www.openfst.org for extensive documentation on this weighted
 // finite-state transducer library.
 //
@@ -27,15 +41,15 @@ int farinfo_main(int argc, char **argv) {
   SET_FLAGS(usage.c_str(), &argc, &argv, true);
   s::ExpandArgs(argc, argv, &argc, &argv);
 
-  std::vector<std::string> in_sources;
-  for (int i = 1; i < argc; ++i) in_sources.push_back(argv[i]);
-  if (in_sources.empty()) in_sources.push_back("");
+  std::vector<std::string> sources;
+  for (int i = 1; i < argc; ++i) sources.push_back(argv[i]);
+  if (sources.empty()) sources.push_back("");
 
-  const auto arc_type = s::LoadArcTypeFromFar(in_sources[0]);
+  const auto arc_type = s::LoadArcTypeFromFar(sources[0]);
   if (arc_type.empty()) return 1;
 
-  s::FarInfo(in_sources, arc_type, FLAGS_begin_key, FLAGS_end_key,
-             FLAGS_list_fsts);
+  s::Info(sources, arc_type, FST_FLAGS_begin_key,
+          FST_FLAGS_end_key, FST_FLAGS_list_fsts);
 
   return 0;
 }
