@@ -1,3 +1,17 @@
+// Copyright 2005-2020 Google LLC
+//
+// Licensed under the Apache License, Version 2.0 (the 'License');
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an 'AS IS' BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+//
 // See www.openfst.org for extensive documentation on this weighted
 // finite-state transducer library.
 //
@@ -7,6 +21,7 @@
 
 #include <fst/extensions/far/getters.h>
 
+#include <cstdint>
 #include <string>
 #include <vector>
 
@@ -16,7 +31,7 @@ namespace fst {
 
 namespace script {
 
-bool GetFarType(const std::string &str, FarType *far_type) {
+bool GetFarType(std::string_view str, FarType *far_type) {
   if (str == "fst") {
     *far_type = FarType::FST;
   } else if (str == "stlist") {
@@ -31,7 +46,7 @@ bool GetFarType(const std::string &str, FarType *far_type) {
   return true;
 }
 
-bool GetFarEntryType(const std::string &str, FarEntryType *entry_type) {
+bool GetFarEntryType(std::string_view str, FarEntryType *entry_type) {
   if (str == "line") {
     *entry_type = FarEntryType::LINE;
   } else if (str == "file") {
