@@ -1,3 +1,17 @@
+// Copyright 2005-2020 Google LLC
+//
+// Licensed under the Apache License, Version 2.0 (the 'License');
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an 'AS IS' BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+//
 // See www.openfst.org for extensive documentation on this weighted
 // finite-state transducer library.
 //
@@ -20,12 +34,7 @@ std::string LoadArcTypeFromFar(const std::string &far_source) {
     LOG(ERROR) << "Error reading FAR: " << far_source;
     return "";
   }
-  std::string atype = hdr.ArcType();
-  if (atype == "unknown") {
-    LOG(ERROR) << "Empty FST archive: " << far_source;
-    return "";
-  }
-  return atype;
+  return hdr.ArcType();
 }
 
 std::string LoadArcTypeFromFst(const std::string &fst_source) {
