@@ -1,6 +1,22 @@
+// Copyright 2005-2020 Google LLC
+//
+// Licensed under the Apache License, Version 2.0 (the 'License');
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an 'AS IS' BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+//
 // See www.openfst.org for extensive documentation on this weighted
 // finite-state transducer library.
 
+#include <string>
+
 #include <fst/flags.h>
 #include <fst/log.h>
 #include <fst/extensions/linear/linear-fst.h>
@@ -43,7 +59,8 @@ int fstloglinearapply_main(int argc, char **argv) {
 
   fst::StdVectorFst ofst;
 
-  fst::LogLinearApply(*ifst1, *ifst2, &ofst, FLAGS_normalize);
+  fst::LogLinearApply(*ifst1, *ifst2, &ofst,
+                          FST_FLAGS_normalize);
 
   return !ofst.Write(out_name);
 }
