@@ -1,3 +1,17 @@
+// Copyright 2005-2020 Google LLC
+//
+// Licensed under the Apache License, Version 2.0 (the 'License');
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an 'AS IS' BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+//
 // See www.openfst.org for extensive documentation on this weighted
 // finite-state transducer library.
 
@@ -18,10 +32,6 @@ DEFINE_string(phi_fst_rewrite_mode, "auto",
 
 namespace fst {
 
-const char phi_fst_type[] = "phi";
-const char input_phi_fst_type[] = "input_phi";
-const char output_phi_fst_type[] = "output_phi";
-
 REGISTER_FST(PhiFst, StdArc);
 REGISTER_FST(PhiFst, LogArc);
 REGISTER_FST(PhiFst, Log64Arc);
