@@ -1,3 +1,17 @@
+// Copyright 2005-2020 Google LLC
+//
+// Licensed under the Apache License, Version 2.0 (the 'License');
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an 'AS IS' BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+//
 // See www.openfst.org for extensive documentation on this weighted
 // finite-state transducer library.
 
@@ -6,18 +20,20 @@
 #include <cstring>
 #include <ostream>
 #include <sstream>
+#include <string>
 #include <utility>
 
 #include <fst/log.h>
 #include <fstream>
 #include <fst/util.h>
 #include <fst/windows_defs.inc>
+#include <string_view>
 
 namespace fst {
 namespace script {
 
 // Reads vector of weights; returns true on success.
-bool ReadPotentials(const std::string &weight_type, const std::string &source,
+bool ReadPotentials(std::string_view weight_type, const std::string &source,
                     std::vector<WeightClass> *potentials) {
   std::ifstream istrm(source);
   if (!istrm) {
@@ -30,9 +46,9 @@ bool ReadPotentials(const std::string &weight_type, const std::string &source,
   potentials->clear();
   while (!istrm.getline(line, kLineLen).fail()) {
     ++nline;
-    std::vector<char *> col;
-    SplitString(line, "\n\t ", &col, true);
-    if (col.empty() || col[0][0] == '\0') continue;
+    std::vector<std::string_view> col =
+        StrSplit(line, ByAnyChar("\n\t "), SkipEmpty());
+    if (col.empty() || col[0].empty()) continue;
     if (col.size() != 2) {
       FSTERROR() << "ReadPotentials: Bad number of columns, "
                  << "file = " << source << ", line = " << nline;
